
# This file is automatically generated by setup.py, So don't edit it. :)
VERSION_INFO = {
    'final': True,
    'version': '1.6.3',
    'branch_nick': '(detached',
    'revision_id': '0659213143d3e62752954ee77a3672a9da8e7e7d',
    'revno': 4083
}
